import setuptools


setuptools.setup(
    name='3-py',
    version='0.0.2',
    author='Vladimir Chebotarev',
    description='Tree tool written in Python',
    packages=[],
    scripts=['3'],
    install_requires=[]
)
